========== Claun help ========== Parameter entity ================== :Author: Jiri Chadima :Version: 2012/04/18 Description ----------- Parameter represents one configuration option of the whole environment. The configuration is stored in **couchDB** as a single JSON document. By using the administration form, you can let the server create the document for you. A full example configuration document can be seen in the configuration.json_ file. Some fields in the document are generated by the server. They are described in the appropriate module. Form fields ---------------- The fields in the **parameter** form are: - **Name** - name of the parameter for the framework configuration builder. Like 'stereo'. - **Human name** - Name that is displayed to the user, like 'Stereo'. - **Type** - This field specifies how the user could influence the parameter's value. If you just need to pass a single value that a user can not change, use dropdown with one value. +-----------+--------------------------------------------------------------+ | Name | Description | +===========+==============================================================+ | dropdown | You provide multiple options and user has to choose one. | | | It is possible to pick a default one that is pre-selected. | +-----------+--------------------------------------------------------------+ | slider | Numeric (float/integer) value in a range | +-----------+--------------------------------------------------------------+ | boolean | Toggle button, value is either on or off | +-----------+--------------------------------------------------------------+ - **Group** - You can group parameters in groups. Typical usage is to have a separate group for projections (supported group name is 'projection'). Grouping parameters together may influence displaying parameters to the user or their processing during application startup. - **Help text** - Some helpful text that can explain what the parameter does. - **User editable** - Whether a user can edit the parameter; you may want some parameters to be fixed to some value Names and values of parameters are processed during application startup by framework configuration builders. See `their documentation`_ for supported parameters. .. _computer.json: computer.json .. _configuration.json: configuration.json .. _`their documentation`: /distribappcontrol/admin/help/index.html